This project contains lists of first and last names for different cultural groups and countries, compiled from data freely available on the internet. There are individual lists for each country/culture, listed by the ISO language code for the associated language.

Two sets of lists are maintained, if appropriate. The primary list is a normalized one, where all non-ASCII vowels have been replaced by their ASCII equivalents. This is because of the frequency with which vowels lose their accents when surnames are moved across cultural or national frontiers. Non-ASCII consonants have been retained, as these characters are more commonly preserved. However, replacing these characters with their ASCII equivalents is straightforward, if desired. Non-normalized versions of these lists are also maintained, where the original database/list includes non-ASCII vowels.

These lists have been retrieved from the internet, and thus are no more complete than the databases that are publicly available. In all cases, credit for the different lists is provided in the `credits.txt` file associated with this project. Publicly available lists with little likelihood of copyright violation have been chosen.

Erik Norvelle  
erik dot norvelle at neomailbox dot net
